@@ -71,6 +71,7 @@ from asposewordscloud.models.files_list import FilesList
 from asposewordscloud.models.files_upload_result import FilesUploadResult
 from asposewordscloud.models.fixed_page_save_options_data import FixedPageSaveOptionsData
 from asposewordscloud.models.font import Font
+from asposewordscloud.models.font_dto import FontDto
 from asposewordscloud.models.font_info import FontInfo
 from asposewordscloud.models.font_response import FontResponse
 from asposewordscloud.models.footnote import Footnote
@@ -157,8 +158,10 @@ from asposewordscloud.models.protection_data_response import ProtectionDataRespo
 from asposewordscloud.models.protection_request import ProtectionRequest
 from asposewordscloud.models.ps_save_options_data import PsSaveOptionsData
 from asposewordscloud.models.range_document import RangeDocument
+from asposewordscloud.models.range_document_dto import RangeDocumentDto
 from asposewordscloud.models.range_text_response import RangeTextResponse
 from asposewordscloud.models.replace_range import ReplaceRange
+from asposewordscloud.models.replace_range_dto import ReplaceRangeDto
 from asposewordscloud.models.replace_text_parameters import ReplaceTextParameters
 from asposewordscloud.models.replace_text_response import ReplaceTextResponse
 from asposewordscloud.models.report_build_options import ReportBuildOptions
@@ -203,20 +206,26 @@ from asposewordscloud.models.svg_save_options_data import SvgSaveOptionsData
 from asposewordscloud.models.table import Table
 from asposewordscloud.models.table_cell import TableCell
 from asposewordscloud.models.table_cell_format import TableCellFormat
+from asposewordscloud.models.table_cell_format_dto import TableCellFormatDto
 from asposewordscloud.models.table_cell_format_response import TableCellFormatResponse
 from asposewordscloud.models.table_cell_insert import TableCellInsert
+from asposewordscloud.models.table_cell_insert_dto import TableCellInsertDto
 from asposewordscloud.models.table_cell_response import TableCellResponse
 from asposewordscloud.models.table_insert import TableInsert
+from asposewordscloud.models.table_insert_dto import TableInsertDto
 from asposewordscloud.models.table_link import TableLink
 from asposewordscloud.models.table_link_collection import TableLinkCollection
 from asposewordscloud.models.table_link_collection_response import TableLinkCollectionResponse
 from asposewordscloud.models.table_properties import TableProperties
+from asposewordscloud.models.table_properties_dto import TablePropertiesDto
 from asposewordscloud.models.table_properties_response import TablePropertiesResponse
 from asposewordscloud.models.table_response import TableResponse
 from asposewordscloud.models.table_row import TableRow
 from asposewordscloud.models.table_row_format import TableRowFormat
+from asposewordscloud.models.table_row_format_dto import TableRowFormatDto
 from asposewordscloud.models.table_row_format_response import TableRowFormatResponse
 from asposewordscloud.models.table_row_insert import TableRowInsert
+from asposewordscloud.models.table_row_insert_dto import TableRowInsertDto
 from asposewordscloud.models.table_row_response import TableRowResponse
 from asposewordscloud.models.tab_stop import TabStop
 from asposewordscloud.models.tab_stop_base import TabStopBase
