@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="comment_insert.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -87,7 +88,7 @@ class CommentInsert(object):
     def author(self):
         """Gets the author of this CommentInsert.  # noqa: E501
 
-        Gets or sets returns or sets the author name for a comment.  # noqa: E501
+        Gets or sets the author name for a comment.  # noqa: E501
 
         :return: The author of this CommentInsert.  # noqa: E501
         :rtype: str
@@ -98,7 +99,7 @@ class CommentInsert(object):
     def author(self, author):
         """Sets the author of this CommentInsert.
 
-        Gets or sets returns or sets the author name for a comment.  # noqa: E501
+        Gets or sets the author name for a comment.  # noqa: E501
 
         :param author: The author of this CommentInsert.  # noqa: E501
         :type: str
@@ -131,7 +132,7 @@ class CommentInsert(object):
     def initial(self):
         """Gets the initial of this CommentInsert.  # noqa: E501
 
-        Gets or sets returns or sets the initials of the user associated with a specific comment.  # noqa: E501
+        Gets or sets the initials of the user associated with a specific comment.  # noqa: E501
 
         :return: The initial of this CommentInsert.  # noqa: E501
         :rtype: str
@@ -142,7 +143,7 @@ class CommentInsert(object):
     def initial(self, initial):
         """Sets the initial of this CommentInsert.
 
-        Gets or sets returns or sets the initials of the user associated with a specific comment.  # noqa: E501
+        Gets or sets the initials of the user associated with a specific comment.  # noqa: E501
 
         :param initial: The initial of this CommentInsert.  # noqa: E501
         :type: str
@@ -153,7 +154,7 @@ class CommentInsert(object):
     def range_end(self):
         """Gets the range_end of this CommentInsert.  # noqa: E501
 
-        Gets or sets link to comment range end node.  # noqa: E501
+        Gets or sets the link to comment range end node.  # noqa: E501
 
         :return: The range_end of this CommentInsert.  # noqa: E501
         :rtype: DocumentPosition
@@ -164,7 +165,7 @@ class CommentInsert(object):
     def range_end(self, range_end):
         """Sets the range_end of this CommentInsert.
 
-        Gets or sets link to comment range end node.  # noqa: E501
+        Gets or sets the link to comment range end node.  # noqa: E501
 
         :param range_end: The range_end of this CommentInsert.  # noqa: E501
         :type: DocumentPosition
@@ -175,7 +176,7 @@ class CommentInsert(object):
     def range_start(self):
         """Gets the range_start of this CommentInsert.  # noqa: E501
 
-        Gets or sets link to comment range start node.  # noqa: E501
+        Gets or sets the link to comment range start node.  # noqa: E501
 
         :return: The range_start of this CommentInsert.  # noqa: E501
         :rtype: DocumentPosition
@@ -186,7 +187,7 @@ class CommentInsert(object):
     def range_start(self, range_start):
         """Sets the range_start of this CommentInsert.
 
-        Gets or sets link to comment range start node.  # noqa: E501
+        Gets or sets the link to comment range start node.  # noqa: E501
 
         :param range_start: The range_start of this CommentInsert.  # noqa: E501
         :type: DocumentPosition
@@ -197,7 +198,7 @@ class CommentInsert(object):
     def text(self):
         """Gets the text of this CommentInsert.  # noqa: E501
 
-        Gets or sets this is a convenience property that allows to easily get or set text of the comment.  # noqa: E501
+        Gets or sets text of the comment.  # noqa: E501
 
         :return: The text of this CommentInsert.  # noqa: E501
         :rtype: str
@@ -208,7 +209,7 @@ class CommentInsert(object):
     def text(self, text):
         """Sets the text of this CommentInsert.
 
-        Gets or sets this is a convenience property that allows to easily get or set text of the comment.  # noqa: E501
+        Gets or sets text of the comment.  # noqa: E501
 
         :param text: The text of this CommentInsert.  # noqa: E501
         :type: str
@@ -222,21 +223,25 @@ class CommentInsert(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -259,6 +264,8 @@ class CommentInsert(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
