@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="document_entry_list.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -67,7 +68,7 @@ class DocumentEntryList(object):
     def apply_base_document_headers_and_footers_to_appending_documents(self):
         """Gets the apply_base_document_headers_and_footers_to_appending_documents of this DocumentEntryList.  # noqa: E501
 
-        Gets or sets parameter that indicates to apply headers and footers from base document to appending documents. Default is true.  # noqa: E501
+        Gets or sets a value indicating whether to apply headers and footers from base document to appending documents. The default value is true.  # noqa: E501
 
         :return: The apply_base_document_headers_and_footers_to_appending_documents of this DocumentEntryList.  # noqa: E501
         :rtype: bool
@@ -78,7 +79,7 @@ class DocumentEntryList(object):
     def apply_base_document_headers_and_footers_to_appending_documents(self, apply_base_document_headers_and_footers_to_appending_documents):
         """Sets the apply_base_document_headers_and_footers_to_appending_documents of this DocumentEntryList.
 
-        Gets or sets parameter that indicates to apply headers and footers from base document to appending documents. Default is true.  # noqa: E501
+        Gets or sets a value indicating whether to apply headers and footers from base document to appending documents. The default value is true.  # noqa: E501
 
         :param apply_base_document_headers_and_footers_to_appending_documents: The apply_base_document_headers_and_footers_to_appending_documents of this DocumentEntryList.  # noqa: E501
         :type: bool
@@ -89,7 +90,7 @@ class DocumentEntryList(object):
     def document_entries(self):
         """Gets the document_entries of this DocumentEntryList.  # noqa: E501
 
-        Gets or sets list of documents.  # noqa: E501
+        Gets or sets the list of documents.  # noqa: E501
 
         :return: The document_entries of this DocumentEntryList.  # noqa: E501
         :rtype: list[DocumentEntry]
@@ -100,7 +101,7 @@ class DocumentEntryList(object):
     def document_entries(self, document_entries):
         """Sets the document_entries of this DocumentEntryList.
 
-        Gets or sets list of documents.  # noqa: E501
+        Gets or sets the list of documents.  # noqa: E501
 
         :param document_entries: The document_entries of this DocumentEntryList.  # noqa: E501
         :type: list[DocumentEntry]
@@ -114,21 +115,25 @@ class DocumentEntryList(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -151,6 +156,8 @@ class DocumentEntryList(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
