@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="downsample_options_data.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -72,7 +73,7 @@ class DownsampleOptionsData(object):
     def downsample_images(self):
         """Gets the downsample_images of this DownsampleOptionsData.  # noqa: E501
 
-        Gets or sets specifies whether images should be downsampled.  # noqa: E501
+        Gets or sets a value indicating whether images should be downsampled.  # noqa: E501
 
         :return: The downsample_images of this DownsampleOptionsData.  # noqa: E501
         :rtype: bool
@@ -83,7 +84,7 @@ class DownsampleOptionsData(object):
     def downsample_images(self, downsample_images):
         """Sets the downsample_images of this DownsampleOptionsData.
 
-        Gets or sets specifies whether images should be downsampled.  # noqa: E501
+        Gets or sets a value indicating whether images should be downsampled.  # noqa: E501
 
         :param downsample_images: The downsample_images of this DownsampleOptionsData.  # noqa: E501
         :type: bool
@@ -94,7 +95,7 @@ class DownsampleOptionsData(object):
     def resolution(self):
         """Gets the resolution of this DownsampleOptionsData.  # noqa: E501
 
-        Gets or sets specifies the resolution in pixels per inch which the images should be downsampled to.  # noqa: E501
+        Gets or sets the resolution in pixels per inch which the images should be downsampled to.  # noqa: E501
 
         :return: The resolution of this DownsampleOptionsData.  # noqa: E501
         :rtype: int
@@ -105,7 +106,7 @@ class DownsampleOptionsData(object):
     def resolution(self, resolution):
         """Sets the resolution of this DownsampleOptionsData.
 
-        Gets or sets specifies the resolution in pixels per inch which the images should be downsampled to.  # noqa: E501
+        Gets or sets the resolution in pixels per inch which the images should be downsampled to.  # noqa: E501
 
         :param resolution: The resolution of this DownsampleOptionsData.  # noqa: E501
         :type: int
@@ -116,7 +117,7 @@ class DownsampleOptionsData(object):
     def resolution_threshold(self):
         """Gets the resolution_threshold of this DownsampleOptionsData.  # noqa: E501
 
-        Gets or sets specifies the threshold resolution in pixels per inch. If resolution of an image in the document is less than threshold value, the downsampling algorithm will not be applied. A value of 0 means the threshold check is not used and all images that can be reduced in size are downsampled.  # noqa: E501
+        Gets or sets the threshold resolution in pixels per inch. If resolution of an image in the document is less than threshold value, the downsampling algorithm will not be applied. A value of 0 means the threshold check is not used and all images that can be reduced in size are downsampled.  # noqa: E501
 
         :return: The resolution_threshold of this DownsampleOptionsData.  # noqa: E501
         :rtype: int
@@ -127,7 +128,7 @@ class DownsampleOptionsData(object):
     def resolution_threshold(self, resolution_threshold):
         """Sets the resolution_threshold of this DownsampleOptionsData.
 
-        Gets or sets specifies the threshold resolution in pixels per inch. If resolution of an image in the document is less than threshold value, the downsampling algorithm will not be applied. A value of 0 means the threshold check is not used and all images that can be reduced in size are downsampled.  # noqa: E501
+        Gets or sets the threshold resolution in pixels per inch. If resolution of an image in the document is less than threshold value, the downsampling algorithm will not be applied. A value of 0 means the threshold check is not used and all images that can be reduced in size are downsampled.  # noqa: E501
 
         :param resolution_threshold: The resolution_threshold of this DownsampleOptionsData.  # noqa: E501
         :type: int
@@ -141,21 +142,25 @@ class DownsampleOptionsData(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -178,6 +183,8 @@ class DownsampleOptionsData(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
