@@ -43,6 +43,7 @@ class GifSaveOptionsData(object):
                             and the value is json key in definition.
     """
     swagger_types = {
+        'allow_embedding_post_script_fonts': 'bool',
         'dml3_d_effects_rendering_mode': 'str',
         'dml_effects_rendering_mode': 'str',
         'dml_rendering_mode': 'str',
@@ -76,6 +77,7 @@ class GifSaveOptionsData(object):
     }
 
     attribute_map = {
+        'allow_embedding_post_script_fonts': 'AllowEmbeddingPostScriptFonts',
         'dml3_d_effects_rendering_mode': 'Dml3DEffectsRenderingMode',
         'dml_effects_rendering_mode': 'DmlEffectsRenderingMode',
         'dml_rendering_mode': 'DmlRenderingMode',
@@ -108,9 +110,10 @@ class GifSaveOptionsData(object):
         'vertical_resolution': 'VerticalResolution'
     }
 
-    def __init__(self, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, graphics_quality_options=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None):  # noqa: E501
+    def __init__(self, allow_embedding_post_script_fonts=None, dml3_d_effects_rendering_mode=None, dml_effects_rendering_mode=None, dml_rendering_mode=None, file_name=None, save_format=None, update_fields=None, update_last_printed_property=None, update_last_saved_time_property=None, update_sdt_content=None, zip_output=None, color_mode=None, jpeg_quality=None, metafile_rendering_options=None, numeral_format=None, optimize_output=None, page_count=None, page_index=None, graphics_quality_options=None, horizontal_resolution=None, image_brightness=None, image_color_mode=None, image_contrast=None, paper_color=None, pixel_format=None, resolution=None, scale=None, use_anti_aliasing=None, use_gdi_emf_renderer=None, use_high_quality_rendering=None, vertical_resolution=None):  # noqa: E501
         """GifSaveOptionsData - a model defined in Swagger"""  # noqa: E501
 
+        self._allow_embedding_post_script_fonts = None
         self._dml3_d_effects_rendering_mode = None
         self._dml_effects_rendering_mode = None
         self._dml_rendering_mode = None
@@ -143,6 +146,8 @@ class GifSaveOptionsData(object):
         self._vertical_resolution = None
         self.discriminator = None
 
+        if allow_embedding_post_script_fonts is not None:
+            self.allow_embedding_post_script_fonts = allow_embedding_post_script_fonts
         if dml3_d_effects_rendering_mode is not None:
             self.dml3_d_effects_rendering_mode = dml3_d_effects_rendering_mode
         if dml_effects_rendering_mode is not None:
@@ -204,6 +209,28 @@ class GifSaveOptionsData(object):
         if vertical_resolution is not None:
             self.vertical_resolution = vertical_resolution
 
+    @property
+    def allow_embedding_post_script_fonts(self):
+        """Gets the allow_embedding_post_script_fonts of this GifSaveOptionsData.  # noqa: E501
+
+        Gets or sets a boolean value indicating whether to allow embedding fonts with PostScript outlines when embedding TrueType fonts in a document upon it is saved. The default value is false..  # noqa: E501
+
+        :return: The allow_embedding_post_script_fonts of this GifSaveOptionsData.  # noqa: E501
+        :rtype: bool
+        """
+        return self._allow_embedding_post_script_fonts
+
+    @allow_embedding_post_script_fonts.setter
+    def allow_embedding_post_script_fonts(self, allow_embedding_post_script_fonts):
+        """Sets the allow_embedding_post_script_fonts of this GifSaveOptionsData.
+
+        Gets or sets a boolean value indicating whether to allow embedding fonts with PostScript outlines when embedding TrueType fonts in a document upon it is saved. The default value is false..  # noqa: E501
+
+        :param allow_embedding_post_script_fonts: The allow_embedding_post_script_fonts of this GifSaveOptionsData.  # noqa: E501
+        :type: bool
+        """
+        self._allow_embedding_post_script_fonts = allow_embedding_post_script_fonts
+
     @property
     def dml3_d_effects_rendering_mode(self):
         """Gets the dml3_d_effects_rendering_mode of this GifSaveOptionsData.  # noqa: E501
