@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="graphics_quality_options_data.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -87,7 +88,7 @@ class GraphicsQualityOptionsData(object):
     def compositing_mode(self):
         """Gets the compositing_mode of this GraphicsQualityOptionsData.  # noqa: E501
 
-        Gets or sets a value that specifies how composited images are drawn to this Graphics.  # noqa: E501
+        Gets or sets the value, that specifies how composited images are drawn to this Graphics.  # noqa: E501
 
         :return: The compositing_mode of this GraphicsQualityOptionsData.  # noqa: E501
         :rtype: str
@@ -98,7 +99,7 @@ class GraphicsQualityOptionsData(object):
     def compositing_mode(self, compositing_mode):
         """Sets the compositing_mode of this GraphicsQualityOptionsData.
 
-        Gets or sets a value that specifies how composited images are drawn to this Graphics.  # noqa: E501
+        Gets or sets the value, that specifies how composited images are drawn to this Graphics.  # noqa: E501
 
         :param compositing_mode: The compositing_mode of this GraphicsQualityOptionsData.  # noqa: E501
         :type: str
@@ -262,21 +263,25 @@ class GraphicsQualityOptionsData(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -299,6 +304,8 @@ class GraphicsQualityOptionsData(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
