@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="header_footer.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class HeaderFooter(object):
-    """Section element.
+    """DTO container with a section element.
     """
 
     """
@@ -82,7 +83,7 @@ class HeaderFooter(object):
     def link(self):
         """Gets the link of this HeaderFooter.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this HeaderFooter.  # noqa: E501
         :rtype: WordsApiLink
@@ -93,7 +94,7 @@ class HeaderFooter(object):
     def link(self, link):
         """Sets the link of this HeaderFooter.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this HeaderFooter.  # noqa: E501
         :type: WordsApiLink
@@ -104,7 +105,7 @@ class HeaderFooter(object):
     def type(self):
         """Gets the type of this HeaderFooter.  # noqa: E501
 
-        Gets or sets paragraph's text.  # noqa: E501
+        Gets or sets the paragraph's text.  # noqa: E501
 
         :return: The type of this HeaderFooter.  # noqa: E501
         :rtype: str
@@ -115,7 +116,7 @@ class HeaderFooter(object):
     def type(self, type):
         """Sets the type of this HeaderFooter.
 
-        Gets or sets paragraph's text.  # noqa: E501
+        Gets or sets the paragraph's text.  # noqa: E501
 
         :param type: The type of this HeaderFooter.  # noqa: E501
         :type: str
@@ -134,7 +135,7 @@ class HeaderFooter(object):
     def child_nodes(self):
         """Gets the child_nodes of this HeaderFooter.  # noqa: E501
 
-        Gets or sets child nodes.  # noqa: E501
+        Gets or sets the child nodes.  # noqa: E501
 
         :return: The child_nodes of this HeaderFooter.  # noqa: E501
         :rtype: list[NodeLink]
@@ -145,7 +146,7 @@ class HeaderFooter(object):
     def child_nodes(self, child_nodes):
         """Sets the child_nodes of this HeaderFooter.
 
-        Gets or sets child nodes.  # noqa: E501
+        Gets or sets the child nodes.  # noqa: E501
 
         :param child_nodes: The child_nodes of this HeaderFooter.  # noqa: E501
         :type: list[NodeLink]
@@ -156,7 +157,7 @@ class HeaderFooter(object):
     def drawing_objects(self):
         """Gets the drawing_objects of this HeaderFooter.  # noqa: E501
 
-        Gets or sets link to DrawingObjects resource.  # noqa: E501
+        Gets or sets the link to DrawingObjects resource.  # noqa: E501
 
         :return: The drawing_objects of this HeaderFooter.  # noqa: E501
         :rtype: LinkElement
@@ -167,7 +168,7 @@ class HeaderFooter(object):
     def drawing_objects(self, drawing_objects):
         """Sets the drawing_objects of this HeaderFooter.
 
-        Gets or sets link to DrawingObjects resource.  # noqa: E501
+        Gets or sets the link to DrawingObjects resource.  # noqa: E501
 
         :param drawing_objects: The drawing_objects of this HeaderFooter.  # noqa: E501
         :type: LinkElement
@@ -178,7 +179,7 @@ class HeaderFooter(object):
     def paragraphs(self):
         """Gets the paragraphs of this HeaderFooter.  # noqa: E501
 
-        Gets or sets link to Paragraphs resource.  # noqa: E501
+        Gets or sets the link to Paragraphs resource.  # noqa: E501
 
         :return: The paragraphs of this HeaderFooter.  # noqa: E501
         :rtype: LinkElement
@@ -189,7 +190,7 @@ class HeaderFooter(object):
     def paragraphs(self, paragraphs):
         """Sets the paragraphs of this HeaderFooter.
 
-        Gets or sets link to Paragraphs resource.  # noqa: E501
+        Gets or sets the link to Paragraphs resource.  # noqa: E501
 
         :param paragraphs: The paragraphs of this HeaderFooter.  # noqa: E501
         :type: LinkElement
@@ -203,21 +204,25 @@ class HeaderFooter(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -240,6 +245,8 @@ class HeaderFooter(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
