@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="load_web_document_data.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -67,7 +68,7 @@ class LoadWebDocumentData(object):
     def loading_document_url(self):
         """Gets the loading_document_url of this LoadWebDocumentData.  # noqa: E501
 
-        Gets or sets web document url.  # noqa: E501
+        Gets or sets the web document URL.  # noqa: E501
 
         :return: The loading_document_url of this LoadWebDocumentData.  # noqa: E501
         :rtype: str
@@ -78,7 +79,7 @@ class LoadWebDocumentData(object):
     def loading_document_url(self, loading_document_url):
         """Sets the loading_document_url of this LoadWebDocumentData.
 
-        Gets or sets web document url.  # noqa: E501
+        Gets or sets the web document URL.  # noqa: E501
 
         :param loading_document_url: The loading_document_url of this LoadWebDocumentData.  # noqa: E501
         :type: str
@@ -89,7 +90,7 @@ class LoadWebDocumentData(object):
     def save_options(self):
         """Gets the save_options of this LoadWebDocumentData.  # noqa: E501
 
-        Gets or sets save options.  # noqa: E501
+        Gets or sets the save options.  # noqa: E501
 
         :return: The save_options of this LoadWebDocumentData.  # noqa: E501
         :rtype: SaveOptionsData
@@ -100,7 +101,7 @@ class LoadWebDocumentData(object):
     def save_options(self, save_options):
         """Sets the save_options of this LoadWebDocumentData.
 
-        Gets or sets save options.  # noqa: E501
+        Gets or sets the save options.  # noqa: E501
 
         :param save_options: The save_options of this LoadWebDocumentData.  # noqa: E501
         :type: SaveOptionsData
@@ -114,21 +115,25 @@ class LoadWebDocumentData(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -151,6 +156,8 @@ class LoadWebDocumentData(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
