@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="paragraph_link.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -72,7 +73,7 @@ class ParagraphLink(object):
     def link(self):
         """Gets the link of this ParagraphLink.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this ParagraphLink.  # noqa: E501
         :rtype: WordsApiLink
@@ -83,7 +84,7 @@ class ParagraphLink(object):
     def link(self, link):
         """Sets the link of this ParagraphLink.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this ParagraphLink.  # noqa: E501
         :type: WordsApiLink
@@ -94,7 +95,7 @@ class ParagraphLink(object):
     def node_id(self):
         """Gets the node_id of this ParagraphLink.  # noqa: E501
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :return: The node_id of this ParagraphLink.  # noqa: E501
         :rtype: str
@@ -105,7 +106,7 @@ class ParagraphLink(object):
     def node_id(self, node_id):
         """Sets the node_id of this ParagraphLink.
 
-        Gets or sets node id.  # noqa: E501
+        Gets or sets the node id.  # noqa: E501
 
         :param node_id: The node_id of this ParagraphLink.  # noqa: E501
         :type: str
@@ -116,7 +117,7 @@ class ParagraphLink(object):
     def text(self):
         """Gets the text of this ParagraphLink.  # noqa: E501
 
-        Gets or sets paragraph's text.  # noqa: E501
+        Gets or sets the paragraph's text.  # noqa: E501
 
         :return: The text of this ParagraphLink.  # noqa: E501
         :rtype: str
@@ -127,7 +128,7 @@ class ParagraphLink(object):
     def text(self, text):
         """Sets the text of this ParagraphLink.
 
-        Gets or sets paragraph's text.  # noqa: E501
+        Gets or sets the paragraph's text.  # noqa: E501
 
         :param text: The text of this ParagraphLink.  # noqa: E501
         :type: str
@@ -141,21 +142,25 @@ class ParagraphLink(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -178,6 +183,8 @@ class ParagraphLink(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
