@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="protection_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,6 +26,7 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
@@ -72,7 +73,7 @@ class ProtectionRequest(object):
     def new_password(self):
         """Gets the new_password of this ProtectionRequest.  # noqa: E501
 
-        Gets or sets new password.  # noqa: E501
+        Gets or sets the new password.  # noqa: E501
 
         :return: The new_password of this ProtectionRequest.  # noqa: E501
         :rtype: str
@@ -83,7 +84,7 @@ class ProtectionRequest(object):
     def new_password(self, new_password):
         """Sets the new_password of this ProtectionRequest.
 
-        Gets or sets new password.  # noqa: E501
+        Gets or sets the new password.  # noqa: E501
 
         :param new_password: The new_password of this ProtectionRequest.  # noqa: E501
         :type: str
@@ -94,7 +95,7 @@ class ProtectionRequest(object):
     def password(self):
         """Gets the password of this ProtectionRequest.  # noqa: E501
 
-        Gets or sets current password.  # noqa: E501
+        Gets or sets the current password.  # noqa: E501
 
         :return: The password of this ProtectionRequest.  # noqa: E501
         :rtype: str
@@ -105,7 +106,7 @@ class ProtectionRequest(object):
     def password(self, password):
         """Sets the password of this ProtectionRequest.
 
-        Gets or sets current password.  # noqa: E501
+        Gets or sets the current password.  # noqa: E501
 
         :param password: The password of this ProtectionRequest.  # noqa: E501
         :type: str
@@ -116,7 +117,7 @@ class ProtectionRequest(object):
     def protection_type(self):
         """Gets the protection_type of this ProtectionRequest.  # noqa: E501
 
-        Gets or sets new type of protection.  # noqa: E501
+        Gets or sets the new type of protection.  # noqa: E501
 
         :return: The protection_type of this ProtectionRequest.  # noqa: E501
         :rtype: str
@@ -127,7 +128,7 @@ class ProtectionRequest(object):
     def protection_type(self, protection_type):
         """Sets the protection_type of this ProtectionRequest.
 
-        Gets or sets new type of protection.  # noqa: E501
+        Gets or sets the new type of protection.  # noqa: E501
 
         :param protection_type: The protection_type of this ProtectionRequest.  # noqa: E501
         :type: str
@@ -141,21 +142,25 @@ class ProtectionRequest(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -178,6 +183,8 @@ class ProtectionRequest(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
