@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="range_document.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class RangeDocument(object):
-    """Range element.
+    """DTO container with a Range element.
     """
 
     """
@@ -62,7 +63,7 @@ class RangeDocument(object):
     def document_name(self):
         """Gets the document_name of this RangeDocument.  # noqa: E501
 
-        Gets or sets name for new document.  # noqa: E501
+        Gets or sets the name for a new document.  # noqa: E501
 
         :return: The document_name of this RangeDocument.  # noqa: E501
         :rtype: str
@@ -73,7 +74,7 @@ class RangeDocument(object):
     def document_name(self, document_name):
         """Sets the document_name of this RangeDocument.
 
-        Gets or sets name for new document.  # noqa: E501
+        Gets or sets the name for a new document.  # noqa: E501
 
         :param document_name: The document_name of this RangeDocument.  # noqa: E501
         :type: str
@@ -87,21 +88,25 @@ class RangeDocument(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -124,6 +129,8 @@ class RangeDocument(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
