@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="delete_headers_footers_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,15 +23,19 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class DeleteHeadersFootersRequest(object):
+class DeleteHeadersFootersRequest(BaseRequestObject):
     """
     Request model for delete_headers_footers operation.
     Initializes a new instance.
-    :param name The document name.
-    :param section_path Path to parent section.
+    :param name The filename of the input document.
+    :param section_path The path to the section in the document tree.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
@@ -39,7 +43,7 @@ class DeleteHeadersFootersRequest(object):
     :param dest_file_name Result path of the document after the operation. If this parameter is omitted then result of the operation will be saved as the source document.
     :param revision_author Initials of the author to use for revisions.If you set this parameter and then make some changes to the document programmatically, save the document and later open the document in MS Word you will see these changes as revisions.
     :param revision_date_time The date and time to use for revisions.
-    :param headers_footers_types List of types of headers and footers.
+    :param headers_footers_types The list of HeaderFooter types.
     """
 
     def __init__(self, name, section_path, folder=None, storage=None, load_encoding=None, password=None, dest_file_name=None, revision_author=None, revision_date_time=None, headers_footers_types=None):
@@ -119,8 +123,11 @@ class DeleteHeadersFootersRequest(object):
             "form_params": form_params,
             "body": body_params,
             "collection_formats": collection_formats,
-            "response_type": None  # noqa: E501
+            "response_type": 'None'  # noqa: E501
         }
 
     def get_response_type(self):
-        return None  # noqa: E501
\ No newline at end of file
+        return 'None'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return None
