@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="delete_paragraph_tab_stop_request.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -23,17 +23,21 @@
 #  SOFTWARE.
 # </summary>
 # -----------------------------------------------------------------------------------
+import json
 
 from six.moves.urllib.parse import quote
+from asposewordscloud import *
+from asposewordscloud.models.requests import *
+from asposewordscloud.models.responses import *
 
-class DeleteParagraphTabStopRequest(object):
+class DeleteParagraphTabStopRequest(BaseRequestObject):
     """
     Request model for delete_paragraph_tab_stop operation.
     Initializes a new instance.
-    :param name The document name.
-    :param position a tab stop position to remove.
+    :param name The filename of the input document.
+    :param position The position of a tab stop to remove.
     :param index Object index.
-    :param node_path Path to the node which contains paragraph.
+    :param node_path The path to the node in the document tree.
     :param folder Original document folder.
     :param storage Original document storage.
     :param load_encoding Encoding that will be used to load an HTML (or TXT) document if the encoding is not specified in HTML.
@@ -124,4 +128,7 @@ class DeleteParagraphTabStopRequest(object):
         }
 
     def get_response_type(self):
-        return 'TabStopsResponse'  # noqa: E501
\ No newline at end of file
+        return 'TabStopsResponse'  # noqa: E501
+
+    def deserialize_response(self, api_client, response):
+        return self.deserialize(response, TabStopsResponse, api_client)
