@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="section.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class Section(object):
-    """Section element.
+    """DTO container with a section element.
     """
 
     """
@@ -87,7 +88,7 @@ class Section(object):
     def link(self):
         """Gets the link of this Section.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this Section.  # noqa: E501
         :rtype: WordsApiLink
@@ -98,7 +99,7 @@ class Section(object):
     def link(self, link):
         """Sets the link of this Section.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this Section.  # noqa: E501
         :type: WordsApiLink
@@ -109,7 +110,7 @@ class Section(object):
     def child_nodes(self):
         """Gets the child_nodes of this Section.  # noqa: E501
 
-        Gets or sets child nodes.  # noqa: E501
+        Gets or sets the list of child nodes.  # noqa: E501
 
         :return: The child_nodes of this Section.  # noqa: E501
         :rtype: list[NodeLink]
@@ -120,7 +121,7 @@ class Section(object):
     def child_nodes(self, child_nodes):
         """Sets the child_nodes of this Section.
 
-        Gets or sets child nodes.  # noqa: E501
+        Gets or sets the list of child nodes.  # noqa: E501
 
         :param child_nodes: The child_nodes of this Section.  # noqa: E501
         :type: list[NodeLink]
@@ -131,7 +132,7 @@ class Section(object):
     def header_footers(self):
         """Gets the header_footers of this Section.  # noqa: E501
 
-        Gets or sets link to HeaderFooters resource.  # noqa: E501
+        Gets or sets the link to HeaderFooters resource.  # noqa: E501
 
         :return: The header_footers of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -142,7 +143,7 @@ class Section(object):
     def header_footers(self, header_footers):
         """Sets the header_footers of this Section.
 
-        Gets or sets link to HeaderFooters resource.  # noqa: E501
+        Gets or sets the link to HeaderFooters resource.  # noqa: E501
 
         :param header_footers: The header_footers of this Section.  # noqa: E501
         :type: LinkElement
@@ -153,7 +154,7 @@ class Section(object):
     def page_setup(self):
         """Gets the page_setup of this Section.  # noqa: E501
 
-        Gets or sets link to PageSetup resource.  # noqa: E501
+        Gets or sets the link to PageSetup resource.  # noqa: E501
 
         :return: The page_setup of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -164,7 +165,7 @@ class Section(object):
     def page_setup(self, page_setup):
         """Sets the page_setup of this Section.
 
-        Gets or sets link to PageSetup resource.  # noqa: E501
+        Gets or sets the link to PageSetup resource.  # noqa: E501
 
         :param page_setup: The page_setup of this Section.  # noqa: E501
         :type: LinkElement
@@ -175,7 +176,7 @@ class Section(object):
     def paragraphs(self):
         """Gets the paragraphs of this Section.  # noqa: E501
 
-        Gets or sets link to Paragraphs resource.  # noqa: E501
+        Gets or sets the link to Paragraphs resource.  # noqa: E501
 
         :return: The paragraphs of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -186,7 +187,7 @@ class Section(object):
     def paragraphs(self, paragraphs):
         """Sets the paragraphs of this Section.
 
-        Gets or sets link to Paragraphs resource.  # noqa: E501
+        Gets or sets the link to Paragraphs resource.  # noqa: E501
 
         :param paragraphs: The paragraphs of this Section.  # noqa: E501
         :type: LinkElement
@@ -197,7 +198,7 @@ class Section(object):
     def tables(self):
         """Gets the tables of this Section.  # noqa: E501
 
-        Gets or sets link to Tables resource.  # noqa: E501
+        Gets or sets the link to Tables resource.  # noqa: E501
 
         :return: The tables of this Section.  # noqa: E501
         :rtype: LinkElement
@@ -208,7 +209,7 @@ class Section(object):
     def tables(self, tables):
         """Sets the tables of this Section.
 
-        Gets or sets link to Tables resource.  # noqa: E501
+        Gets or sets the link to Tables resource.  # noqa: E501
 
         :param tables: The tables of this Section.  # noqa: E501
         :type: LinkElement
@@ -222,21 +223,25 @@ class Section(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -259,6 +264,8 @@ class Section(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
