@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="table_cell_format.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class TableCellFormat(object):
-    """Represents all formatting for a table row.
+    """DTO container with all formatting for a table row.
     """
 
     """
@@ -122,7 +123,7 @@ class TableCellFormat(object):
     def link(self):
         """Gets the link of this TableCellFormat.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this TableCellFormat.  # noqa: E501
         :rtype: WordsApiLink
@@ -133,7 +134,7 @@ class TableCellFormat(object):
     def link(self, link):
         """Sets the link of this TableCellFormat.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this TableCellFormat.  # noqa: E501
         :type: WordsApiLink
@@ -144,7 +145,7 @@ class TableCellFormat(object):
     def bottom_padding(self):
         """Gets the bottom_padding of this TableCellFormat.  # noqa: E501
 
-        Gets or sets returns or sets the amount of space (in points) to add below the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add below the contents of the cell.  # noqa: E501
 
         :return: The bottom_padding of this TableCellFormat.  # noqa: E501
         :rtype: float
@@ -155,7 +156,7 @@ class TableCellFormat(object):
     def bottom_padding(self, bottom_padding):
         """Sets the bottom_padding of this TableCellFormat.
 
-        Gets or sets returns or sets the amount of space (in points) to add below the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add below the contents of the cell.  # noqa: E501
 
         :param bottom_padding: The bottom_padding of this TableCellFormat.  # noqa: E501
         :type: float
@@ -166,7 +167,7 @@ class TableCellFormat(object):
     def fit_text(self):
         """Gets the fit_text of this TableCellFormat.  # noqa: E501
 
-        Gets or sets if true, fits text in the cell, compressing each paragraph to the width of the cell.  # noqa: E501
+        Gets or sets a value indicating whether to fit text in the cell, compress each paragraph to the width of the cell.  # noqa: E501
 
         :return: The fit_text of this TableCellFormat.  # noqa: E501
         :rtype: bool
@@ -177,7 +178,7 @@ class TableCellFormat(object):
     def fit_text(self, fit_text):
         """Sets the fit_text of this TableCellFormat.
 
-        Gets or sets if true, fits text in the cell, compressing each paragraph to the width of the cell.  # noqa: E501
+        Gets or sets a value indicating whether to fit text in the cell, compress each paragraph to the width of the cell.  # noqa: E501
 
         :param fit_text: The fit_text of this TableCellFormat.  # noqa: E501
         :type: bool
@@ -188,7 +189,7 @@ class TableCellFormat(object):
     def horizontal_merge(self):
         """Gets the horizontal_merge of this TableCellFormat.  # noqa: E501
 
-        Gets or sets specifies how the cell is merged horizontally with other cells in the row.  # noqa: E501
+        Gets or sets the option that controls how the cell is merged horizontally with other cells in the row.  # noqa: E501
 
         :return: The horizontal_merge of this TableCellFormat.  # noqa: E501
         :rtype: str
@@ -199,7 +200,7 @@ class TableCellFormat(object):
     def horizontal_merge(self, horizontal_merge):
         """Sets the horizontal_merge of this TableCellFormat.
 
-        Gets or sets specifies how the cell is merged horizontally with other cells in the row.  # noqa: E501
+        Gets or sets the option that controls how the cell is merged horizontally with other cells in the row.  # noqa: E501
 
         :param horizontal_merge: The horizontal_merge of this TableCellFormat.  # noqa: E501
         :type: str
@@ -218,7 +219,7 @@ class TableCellFormat(object):
     def left_padding(self):
         """Gets the left_padding of this TableCellFormat.  # noqa: E501
 
-        Gets or sets returns or sets the amount of space (in points) to add to the left of the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add to the left of the contents of the cell.  # noqa: E501
 
         :return: The left_padding of this TableCellFormat.  # noqa: E501
         :rtype: float
@@ -229,7 +230,7 @@ class TableCellFormat(object):
     def left_padding(self, left_padding):
         """Sets the left_padding of this TableCellFormat.
 
-        Gets or sets returns or sets the amount of space (in points) to add to the left of the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add to the left of the contents of the cell.  # noqa: E501
 
         :param left_padding: The left_padding of this TableCellFormat.  # noqa: E501
         :type: float
@@ -240,7 +241,7 @@ class TableCellFormat(object):
     def orientation(self):
         """Gets the orientation of this TableCellFormat.  # noqa: E501
 
-        Gets or sets returns or sets the orientation of text in a table cell.  # noqa: E501
+        Gets or sets the orientation of text in a table cell.  # noqa: E501
 
         :return: The orientation of this TableCellFormat.  # noqa: E501
         :rtype: str
@@ -251,7 +252,7 @@ class TableCellFormat(object):
     def orientation(self, orientation):
         """Sets the orientation of this TableCellFormat.
 
-        Gets or sets returns or sets the orientation of text in a table cell.  # noqa: E501
+        Gets or sets the orientation of text in a table cell.  # noqa: E501
 
         :param orientation: The orientation of this TableCellFormat.  # noqa: E501
         :type: str
@@ -270,7 +271,7 @@ class TableCellFormat(object):
     def preferred_width(self):
         """Gets the preferred_width of this TableCellFormat.  # noqa: E501
 
-        Gets or sets returns or sets the preferred width of the cell.  # noqa: E501
+        Gets or sets the preferred width of the cell.  # noqa: E501
 
         :return: The preferred_width of this TableCellFormat.  # noqa: E501
         :rtype: PreferredWidth
@@ -281,7 +282,7 @@ class TableCellFormat(object):
     def preferred_width(self, preferred_width):
         """Sets the preferred_width of this TableCellFormat.
 
-        Gets or sets returns or sets the preferred width of the cell.  # noqa: E501
+        Gets or sets the preferred width of the cell.  # noqa: E501
 
         :param preferred_width: The preferred_width of this TableCellFormat.  # noqa: E501
         :type: PreferredWidth
@@ -292,7 +293,7 @@ class TableCellFormat(object):
     def right_padding(self):
         """Gets the right_padding of this TableCellFormat.  # noqa: E501
 
-        Gets or sets returns or sets the amount of space (in points) to add to the right of the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add to the right of the contents of the cell.  # noqa: E501
 
         :return: The right_padding of this TableCellFormat.  # noqa: E501
         :rtype: float
@@ -303,7 +304,7 @@ class TableCellFormat(object):
     def right_padding(self, right_padding):
         """Sets the right_padding of this TableCellFormat.
 
-        Gets or sets returns or sets the amount of space (in points) to add to the right of the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add to the right of the contents of the cell.  # noqa: E501
 
         :param right_padding: The right_padding of this TableCellFormat.  # noqa: E501
         :type: float
@@ -314,7 +315,7 @@ class TableCellFormat(object):
     def top_padding(self):
         """Gets the top_padding of this TableCellFormat.  # noqa: E501
 
-        Gets or sets returns or sets the amount of space (in points) to add above the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add above the contents of the cell.  # noqa: E501
 
         :return: The top_padding of this TableCellFormat.  # noqa: E501
         :rtype: float
@@ -325,7 +326,7 @@ class TableCellFormat(object):
     def top_padding(self, top_padding):
         """Sets the top_padding of this TableCellFormat.
 
-        Gets or sets returns or sets the amount of space (in points) to add above the contents of cell.  # noqa: E501
+        Gets or sets the amount of space (in points) to add above the contents of the cell.  # noqa: E501
 
         :param top_padding: The top_padding of this TableCellFormat.  # noqa: E501
         :type: float
@@ -336,7 +337,7 @@ class TableCellFormat(object):
     def vertical_alignment(self):
         """Gets the vertical_alignment of this TableCellFormat.  # noqa: E501
 
-        Gets or sets returns or sets the vertical alignment of text in the cell.  # noqa: E501
+        Gets or sets the vertical alignment of text in the cell.  # noqa: E501
 
         :return: The vertical_alignment of this TableCellFormat.  # noqa: E501
         :rtype: str
@@ -347,7 +348,7 @@ class TableCellFormat(object):
     def vertical_alignment(self, vertical_alignment):
         """Sets the vertical_alignment of this TableCellFormat.
 
-        Gets or sets returns or sets the vertical alignment of text in the cell.  # noqa: E501
+        Gets or sets the vertical alignment of text in the cell.  # noqa: E501
 
         :param vertical_alignment: The vertical_alignment of this TableCellFormat.  # noqa: E501
         :type: str
@@ -366,7 +367,7 @@ class TableCellFormat(object):
     def vertical_merge(self):
         """Gets the vertical_merge of this TableCellFormat.  # noqa: E501
 
-        Gets or sets specifies how the cell is merged with other cells vertically.  # noqa: E501
+        Gets or sets the option that controls how the cell is merged with other cells vertically.  # noqa: E501
 
         :return: The vertical_merge of this TableCellFormat.  # noqa: E501
         :rtype: str
@@ -377,7 +378,7 @@ class TableCellFormat(object):
     def vertical_merge(self, vertical_merge):
         """Sets the vertical_merge of this TableCellFormat.
 
-        Gets or sets specifies how the cell is merged with other cells vertically.  # noqa: E501
+        Gets or sets the option that controls how the cell is merged with other cells vertically.  # noqa: E501
 
         :param vertical_merge: The vertical_merge of this TableCellFormat.  # noqa: E501
         :type: str
@@ -418,7 +419,7 @@ class TableCellFormat(object):
     def wrap_text(self):
         """Gets the wrap_text of this TableCellFormat.  # noqa: E501
 
-        Gets or sets if true, wrap text for the cell.  # noqa: E501
+        Gets or sets a value indicating whether to wrap text in the cell.  # noqa: E501
 
         :return: The wrap_text of this TableCellFormat.  # noqa: E501
         :rtype: bool
@@ -429,7 +430,7 @@ class TableCellFormat(object):
     def wrap_text(self, wrap_text):
         """Sets the wrap_text of this TableCellFormat.
 
-        Gets or sets if true, wrap text for the cell.  # noqa: E501
+        Gets or sets a value indicating whether to wrap text in the cell.  # noqa: E501
 
         :param wrap_text: The wrap_text of this TableCellFormat.  # noqa: E501
         :type: bool
@@ -443,21 +444,25 @@ class TableCellFormat(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -480,6 +485,8 @@ class TableCellFormat(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
