@@ -1,7 +1,7 @@
 # coding: utf-8
 # -----------------------------------------------------------------------------------
 # <copyright company="Aspose" file="table_row_format.py">
-#   Copyright (c) 2020 Aspose.Words for Cloud
+#   Copyright (c) 2021 Aspose.Words for Cloud
 # </copyright>
 # <summary>
 #   Permission is hereby granted, free of charge, to any person obtaining a copy
@@ -26,12 +26,13 @@
 import pprint
 import re  # noqa: F401
 
+import datetime
 import six
 import json
 
 
 class TableRowFormat(object):
-    """Represents all formatting for a table row.
+    """DTO container with formatting for a table row.
     """
 
     """
@@ -82,7 +83,7 @@ class TableRowFormat(object):
     def link(self):
         """Gets the link of this TableRowFormat.  # noqa: E501
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :return: The link of this TableRowFormat.  # noqa: E501
         :rtype: WordsApiLink
@@ -93,7 +94,7 @@ class TableRowFormat(object):
     def link(self, link):
         """Sets the link of this TableRowFormat.
 
-        Gets or sets link to the document.  # noqa: E501
+        Gets or sets the link to the document.  # noqa: E501
 
         :param link: The link of this TableRowFormat.  # noqa: E501
         :type: WordsApiLink
@@ -104,7 +105,7 @@ class TableRowFormat(object):
     def allow_break_across_pages(self):
         """Gets the allow_break_across_pages of this TableRowFormat.  # noqa: E501
 
-        Gets or sets true if the text in a table row is allowed to split across a page break.  # noqa: E501
+        Gets or sets a value indicating whether the text in a table row is allowed to split across a page break.  # noqa: E501
 
         :return: The allow_break_across_pages of this TableRowFormat.  # noqa: E501
         :rtype: bool
@@ -115,7 +116,7 @@ class TableRowFormat(object):
     def allow_break_across_pages(self, allow_break_across_pages):
         """Sets the allow_break_across_pages of this TableRowFormat.
 
-        Gets or sets true if the text in a table row is allowed to split across a page break.  # noqa: E501
+        Gets or sets a value indicating whether the text in a table row is allowed to split across a page break.  # noqa: E501
 
         :param allow_break_across_pages: The allow_break_across_pages of this TableRowFormat.  # noqa: E501
         :type: bool
@@ -126,7 +127,7 @@ class TableRowFormat(object):
     def heading_format(self):
         """Gets the heading_format of this TableRowFormat.  # noqa: E501
 
-        Gets or sets true if the row is repeated as a table heading on every page when the table spans more than one page.  # noqa: E501
+        Gets or sets a value indicating whether the row is repeated as a table heading on every page when the table spans more than one page.  # noqa: E501
 
         :return: The heading_format of this TableRowFormat.  # noqa: E501
         :rtype: bool
@@ -137,7 +138,7 @@ class TableRowFormat(object):
     def heading_format(self, heading_format):
         """Sets the heading_format of this TableRowFormat.
 
-        Gets or sets true if the row is repeated as a table heading on every page when the table spans more than one page.  # noqa: E501
+        Gets or sets a value indicating whether the row is repeated as a table heading on every page when the table spans more than one page.  # noqa: E501
 
         :param heading_format: The heading_format of this TableRowFormat.  # noqa: E501
         :type: bool
@@ -203,21 +204,25 @@ class TableRowFormat(object):
 
         for attr, _ in six.iteritems(self.swagger_types):
             value = getattr(self, attr)
+            if value is None:
+                continue
             if isinstance(value, list):
-                result[attr] = list(map(
+                result[self.attribute_map[attr]] = list(map(
                     lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                     value
                 ))
             elif hasattr(value, "to_dict"):
-                result[attr] = value.to_dict()
+                result[self.attribute_map[attr]] = value.to_dict()
             elif isinstance(value, dict):
-                result[attr] = dict(map(
+                result[self.attribute_map[attr]] = dict(map(
                     lambda item: (item[0], item[1].to_dict())
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
-                result[attr] = value
+                result[self.attribute_map[attr]] = value
 
         return result
 
@@ -240,6 +245,8 @@ class TableRowFormat(object):
                     if hasattr(item[1], "to_dict") else item,
                     value.items()
                 ))
+            elif isinstance(value, (datetime.datetime, datetime.date)):
+                result[self.attribute_map[attr]] = value.isoformat()
             else:
                 result[self.attribute_map[attr]] = value
 
